Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(266)

Unified Diff: webkit/media/buffered_data_source.h

Issue 10543007: Add CORS-awareness to HTML5 media elements. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: . Created 8 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « webkit/media/android/webmediaplayer_android.cc ('k') | webkit/media/buffered_data_source.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: webkit/media/buffered_data_source.h
diff --git a/webkit/media/buffered_data_source.h b/webkit/media/buffered_data_source.h
index fd97592154817c1d3b519cc86124c5a0fd03caba..7e743d15419236cea53d00098b26352b30a267ac 100644
--- a/webkit/media/buffered_data_source.h
+++ b/webkit/media/buffered_data_source.h
@@ -35,12 +35,14 @@ class BufferedDataSource : public media::DataSource {
WebKit::WebFrame* frame,
media::MediaLog* media_log);
// Initialize this object using |url|. This object calls |status_cb| when
// initialization has completed.
//
// Method called on the render thread.
- void Initialize(const GURL& url,
- const media::PipelineStatusCB& status_cb);
+ void Initialize(
+ const GURL& url,
+ BufferedResourceLoader::CORSMode cors_mode,
+ const media::PipelineStatusCB& status_cb);
// Adjusts the buffering algorithm based on the given preload value.
void SetPreload(Preload preload);
@@ -139,6 +141,8 @@ class BufferedDataSource : public media::DataSource {
// URL of the resource requested.
GURL url_;
+ // crossorigin attribute on the corresponding HTML media element, if any.
+ BufferedResourceLoader::CORSMode cors_mode_;
// Members for total bytes of the requested object. It is written once on
// render thread but may be read from any thread. However reading of this
« no previous file with comments | « webkit/media/android/webmediaplayer_android.cc ('k') | webkit/media/buffered_data_source.cc » ('j') | no next file with comments »
@@ -35,12 +35,14 @@ class BufferedDataSource : public media::DataSource {
WebKit::WebFrame* frame,
media::MediaLog* media_log);
- // Initialize this object using |url|. This object calls |status_cb| when
- // initialization has completed.
+ // Initialize this object using |url| and |cors_mode|, and call |status_cb|
+ // when initialization has completed.
//
// Method called on the render thread.

Powered by Google App Engine
This is Rietveld 408576698